@@ -22,6 +22,7 @@ namespace stan {
     struct assignment;
     struct assgn;
     struct binary_op;
+    struct conditional_op;
     struct conditional_statement;
     struct distribution;
     struct double_var_decl;
@@ -50,6 +51,7 @@ namespace stan {
     struct sample;
     struct simplex_var_decl;
     struct integrate_ode;
+    struct integrate_ode_control;
     struct unit_vector_var_decl;
     struct statement;
     struct statements;
@@ -71,6 +73,25 @@ namespace stan {
     const int MATRIX_T = 5;
     const int ILL_FORMED_T = 6;
 
+    typedef int var_origin;
+    const int model_name_origin = 0;
+    const int data_origin = 1;
+    const int transformed_data_origin = 2;
+    const int parameter_origin = 3;
+    const int transformed_parameter_origin = 4;
+    const int derived_origin = 5;
+    const int local_origin = 6;
+    const int function_argument_origin = 7;
+    const int function_argument_origin_lp = 8;
+    const int function_argument_origin_rng = 9;
+    const int void_function_argument_origin = 10;
+    const int void_function_argument_origin_lp = 11;
+    const int void_function_argument_origin_rng = 12;
+
+    bool is_data_origin(const var_origin& vo);
+    void print_var_origin(std::ostream& o, const var_origin& vo);
+
+
     std::ostream& write_base_expr_type(std::ostream& o, base_expr_type type);
 
     struct expr_type {
@@ -177,6 +198,7 @@ namespace stan {
       bool is_defined(const std::string& name,
                       const function_signature_t& sig);
       std::set<std::string> key_set() const;
+      bool has_key(const std::string& key) const;
 
     private:
       function_signatures();
@@ -207,11 +229,12 @@ namespace stan {
       expr_type operator()(const variable& e) const;
       expr_type operator()(const fun& e) const;
       expr_type operator()(const integrate_ode& e) const;
+      expr_type operator()(const integrate_ode_control& e) const;
       expr_type operator()(const index_op& e) const;
       expr_type operator()(const index_op_sliced& e) const;
+      expr_type operator()(const conditional_op& e) const;
       expr_type operator()(const binary_op& e) const;
       expr_type operator()(const unary_op& e) const;
-      // template <typename T> expr_type operator()(const T& e) const;
     };
 
 
@@ -224,9 +247,11 @@ namespace stan {
                              boost::recursive_wrapper<array_literal>,
                              boost::recursive_wrapper<variable>,
                              boost::recursive_wrapper<integrate_ode>,
+                             boost::recursive_wrapper<integrate_ode_control>,
                              boost::recursive_wrapper<fun>,
                              boost::recursive_wrapper<index_op>,
                              boost::recursive_wrapper<index_op_sliced>,
+                             boost::recursive_wrapper<conditional_op>,
                              boost::recursive_wrapper<binary_op>,
                              boost::recursive_wrapper<unary_op> >
       expression_t;
@@ -242,8 +267,10 @@ namespace stan {
       expression(const variable& expr);  // NOLINT(runtime/explicit)
       expression(const fun& expr);  // NOLINT(runtime/explicit)
       expression(const integrate_ode& expr);  // NOLINT(runtime/explicit)
+      expression(const integrate_ode_control& expr);  // NOLINT
       expression(const index_op& expr);  // NOLINT(runtime/explicit)
       expression(const index_op_sliced& expr);  // NOLINT(runtime/explicit)
+      expression(const conditional_op& expr);  // NOLINT(runtime/explicit)
       expression(const binary_op& expr);  // NOLINT(runtime/explicit)
       expression(const unary_op& expr);  // NOLINT(runtime/explicit)
       expression(const expression_t& expr_);  // NOLINT(runtime/explicit)
@@ -281,9 +308,11 @@ namespace stan {
       bool operator()(const array_literal& x) const;  // NOLINT
       bool operator()(const variable& x) const;  // NOLINT(runtime/explicit)
       bool operator()(const integrate_ode& x) const;  // NOLINT
+      bool operator()(const integrate_ode_control& x) const;  // NOLINT
       bool operator()(const fun& x) const;  // NOLINT(runtime/explicit)
       bool operator()(const index_op& x) const;  // NOLINT(runtime/explicit)
       bool operator()(const index_op_sliced& x) const;  // NOLINT
+      bool operator()(const conditional_op& x) const;  // NOLINT
       bool operator()(const binary_op& x) const;  // NOLINT(runtime/explicit)
       bool operator()(const unary_op& x) const;  // NOLINT(runtime/explicit)
     };
@@ -335,6 +364,7 @@ namespace stan {
     };
 
     struct integrate_ode {
+      std::string integration_function_name_;
       std::string system_function_name_;
       expression y0_;  // initial state
       expression t0_;  // initial time
@@ -343,23 +373,51 @@ namespace stan {
       expression x_;  // data
       expression x_int_;  // integer data
       integrate_ode();
-      integrate_ode(const std::string& system_function_name,
-                const expression& y0,
-                const expression& t0,
-                const expression& ts,
-                const expression& theta,
-                const expression& x,
-                const expression& x_int);
+      integrate_ode(const std::string& integration_function_name,
+                    const std::string& system_function_name,
+                    const expression& y0,
+                    const expression& t0,
+                    const expression& ts,
+                    const expression& theta,
+                    const expression& x,
+                    const expression& x_int);
+    };
+
+    struct integrate_ode_control {
+      std::string integration_function_name_;
+      std::string system_function_name_;
+      expression y0_;  // initial state
+      expression t0_;  // initial time
+      expression ts_;  // solution times
+      expression theta_;  // params
+      expression x_;  // data
+      expression x_int_;  // integer data
+      expression rel_tol_;  // relative tolerance
+      expression abs_tol_;  // absolute tolerance
+      expression max_num_steps_;  // max number of steps
+      integrate_ode_control();
+      integrate_ode_control(const std::string& integration_function_name,
+                            const std::string& system_function_name,
+                            const expression& y0,
+                            const expression& t0,
+                            const expression& ts,
+                            const expression& theta,
+                            const expression& x,
+                            const expression& x_int,
+                            const expression& rel_tol,
+                            const expression& abs_tol,
+                            const expression& max_num_steps);
     };
 
     struct fun {
       std::string name_;
+      std::string original_name_;
       std::vector<expression> args_;
       expr_type type_;
       fun();
       fun(std::string const& name,
           std::vector<expression> const& args);
-      void infer_type();  // FIXME: is this used anywhere?
+      //      void infer_type();  // FIXME: is this used anywhere?
     };
 
     size_t total_dims(const std::vector<std::vector<expression> >& dimss);
@@ -383,6 +441,19 @@ namespace stan {
       void infer_type();
     };
 
+    struct conditional_op {
+      expression cond_;  // conditional - must be int val
+      expression true_val_;
+      expression false_val_;
+      expr_type type_;
+      var_origin origin_;
+      conditional_op();
+      conditional_op(const expression& cond,
+                     const expression& true_val,
+                     const expression& false_val);
+      bool is_data() const;
+    };
+
     struct binary_op {
       std::string op;
       expression left;
@@ -487,22 +558,6 @@ namespace stan {
       void infer_type();
     };
 
-    typedef int var_origin;
-    const int model_name_origin = 0;
-    const int data_origin = 1;
-    const int transformed_data_origin = 2;
-    const int parameter_origin = 3;
-    const int transformed_parameter_origin = 4;
-    const int derived_origin = 5;
-    const int local_origin = 6;
-    const int function_argument_origin = 7;
-    const int function_argument_origin_lp = 8;
-    const int function_argument_origin_rng = 9;
-    const int void_function_argument_origin = 10;
-    const int void_function_argument_origin_lp = 11;
-    const int void_function_argument_origin_rng = 12;
-
-    void print_var_origin(std::ostream& o, const var_origin& vo);
 
     struct base_var_decl {
       std::string name_;
@@ -625,9 +680,9 @@ namespace stan {
     struct cholesky_corr_var_decl : public base_var_decl {
       expression K_;
       cholesky_corr_var_decl();
-      cholesky_corr_var_decl(const expression& K,
-                             const std::string& name,
-                             const std::vector<expression>& dims);
+      cholesky_corr_var_decl(expression const& K,
+                             std::string const& name,
+                             std::vector<expression> const& dims);
     };
 
     struct cov_matrix_var_decl : public base_var_decl {
@@ -665,8 +720,24 @@ namespace stan {
       std::string operator()(const corr_matrix_var_decl& x) const;
     };
 
-
-
+    struct var_decl_base_type_vis
+      : public boost::static_visitor<base_var_decl> {
+      var_decl_base_type_vis();
+      base_var_decl operator()(const nil& x) const;
+      base_var_decl operator()(const int_var_decl& x) const;
+      base_var_decl operator()(const double_var_decl& x) const;
+      base_var_decl operator()(const vector_var_decl& x) const;
+      base_var_decl operator()(const row_vector_var_decl& x) const;
+      base_var_decl operator()(const matrix_var_decl& x) const;
+      base_var_decl operator()(const simplex_var_decl& x) const;
+      base_var_decl operator()(const unit_vector_var_decl& x) const;
+      base_var_decl operator()(const ordered_var_decl& x) const;
+      base_var_decl operator()(const positive_ordered_var_decl& x) const;
+      base_var_decl operator()(const cholesky_factor_var_decl& x) const;
+      base_var_decl operator()(const cholesky_corr_var_decl& x) const;
+      base_var_decl operator()(const cov_matrix_var_decl& x) const;
+      base_var_decl operator()(const corr_matrix_var_decl& x) const;
+    };
 
     struct var_decl {
       typedef boost::variant<boost::recursive_wrapper<nil>,
@@ -708,6 +779,7 @@ namespace stan {
       var_decl(const corr_matrix_var_decl& decl);  // NOLINT(runtime/explicit)
 
       std::string name() const;
+      base_var_decl base_decl() const;
     };
 
     struct statement {
@@ -935,8 +1007,10 @@ namespace stan {
       bool operator()(const variable& e) const;
       bool operator()(const fun& e) const;
       bool operator()(const integrate_ode& e) const;
+      bool operator()(const integrate_ode_control& e) const;
       bool operator()(const index_op& e) const;
       bool operator()(const index_op_sliced& e) const;
+      bool operator()(const conditional_op& e) const;
       bool operator()(const binary_op& e) const;
       bool operator()(const unary_op& e) const;
     };
@@ -987,9 +1061,11 @@ namespace stan {
       bool operator()(const array_literal& e) const;
       bool operator()(const variable& e) const;
       bool operator()(const integrate_ode& e) const;
+      bool operator()(const integrate_ode_control& e) const;
       bool operator()(const fun& e) const;
       bool operator()(const index_op& e) const;
       bool operator()(const index_op_sliced& e) const;
+      bool operator()(const conditional_op& e) const;
       bool operator()(const binary_op& e) const;
       bool operator()(const unary_op& e) const;
     };
@@ -1007,9 +1083,11 @@ namespace stan {
       bool operator()(const array_literal& e) const;
       bool operator()(const variable& e) const;
       bool operator()(const integrate_ode& e) const;
+      bool operator()(const integrate_ode_control& e) const;
       bool operator()(const fun& e) const;
       bool operator()(const index_op& e) const;
       bool operator()(const index_op_sliced& e) const;
+      bool operator()(const conditional_op& e) const;
       bool operator()(const binary_op& e) const;
       bool operator()(const unary_op& e) const;
     };
@@ -1026,7 +1104,24 @@ namespace stan {
     bool ends_with(const std::string& suffix,
                    const std::string& s);
 
+
+    std::string get_cdf(const std::string& dist_name);
+
+    std::string get_ccdf(const std::string& dist_name);
+
+    std::string get_prob_fun(const std::string& dist_name);
+
+    bool has_prob_fun_suffix(const std::string& name);
+    std::string strip_prob_fun_suffix(const std::string& dist_fun);
+
+    bool has_cdf_suffix(const std::string& name);
+    std::string strip_cdf_suffix(const std::string& dist_fun);
+
+    bool has_ccdf_suffix(const std::string& name);
+    std::string strip_ccdf_suffix(const std::string& dist_fun);
+
+    bool fun_name_exists(const std::string& name);
+
   }
 }
-
 #endif
