@@ -19,49 +19,52 @@ namespace stan {
         _subarguments.clear();
       }
 
-      void print(std::ostream* s, const int depth, const std::string prefix) {
-        if (!s)
-          return;
+      void print(interface_callbacks::writer::base_writer& w,
+                 const int depth,
+                 const std::string& prefix) {
         std::string indent(compute_indent(depth), ' ');
-        *s << prefix << indent << _name << std::endl;
+        w(prefix + indent + _name);
 
         for (std::vector<argument*>::iterator it = _subarguments.begin();
              it != _subarguments.end(); ++it)
-          (*it)->print(s, depth + 1, prefix);
+          (*it)->print(w, depth + 1, prefix);
       }
 
-      void print_help(std::ostream* s, const int depth, const bool recurse) {
-        if (!s)
-          return;
-
+      void print_help(interface_callbacks::writer::base_writer& w,
+                      const int depth,
+                      const bool recurse) {
         std::string indent(indent_width * depth, ' ');
         std::string subindent(indent_width, ' ');
 
-        *s << indent << _name << std::endl;
-        *s << indent << subindent << _description << std::endl;
+        w(indent + _name);
+        w(indent + subindent + _description);
         if (_subarguments.size() > 0) {
-          *s << indent << subindent << "Valid subarguments:";
+          std::stringstream ss;
+          ss << indent << subindent << "Valid subarguments:";
 
           std::vector<argument*>::iterator it = _subarguments.begin();
-          *s << " " << (*it)->name();
+          ss << " " << (*it)->name();
           ++it;
 
           for (; it != _subarguments.end(); ++it)
-            *s << ", " << (*it)->name();
-          *s << std::endl << std::endl;
+            ss << ", " << (*it)->name();
+          w(ss.str());
+          w();
 
           if (recurse) {
             for (std::vector<argument*>::iterator it = _subarguments.begin();
                  it != _subarguments.end(); ++it)
-              (*it)->print_help(s, depth + 1, true);
+              (*it)->print_help(w, depth + 1, true);
           }
         } else {
-          *s << std::endl;
+          w();
         }
       }
 
-      bool parse_args(std::vector<std::string>& args, std::ostream* out,
-                      std::ostream* err, bool& help_flag) {
+      bool parse_args(std::vector<std::string>& args,
+                      interface_callbacks::writer::base_writer& info,
+                      interface_callbacks::writer::base_writer& err,
+                      bool& help_flag) {
         bool good_arg = true;
         bool valid_arg = true;
 
@@ -74,12 +77,12 @@ namespace stan {
           std::string cat_name = args.back();
 
           if (cat_name == "help") {
-            print_help(out, 0, false);
+            print_help(info, 0, false);
             help_flag |= true;
             args.clear();
             return true;
           } else if (cat_name == "help-all") {
-            print_help(out, 0, true);
+            print_help(info, 0, true);
             help_flag |= true;
             args.clear();
             return true;
@@ -95,11 +98,11 @@ namespace stan {
                it != _subarguments.end(); ++it) {
             if ((*it)->name() == cat_name) {
               args.pop_back();
-              valid_arg &= (*it)->parse_args(args, out, err, help_flag);
+              valid_arg &= (*it)->parse_args(args, info, err, help_flag);
               good_arg = true;
               break;
             } else if ( (*it)->name() == val_name ) {
-              valid_arg &= (*it)->parse_args(args, out, err, help_flag);
+              valid_arg &= (*it)->parse_args(args, info, err, help_flag);
               good_arg = true;
               break;
             } else {
@@ -110,29 +113,30 @@ namespace stan {
         return valid_arg;
       }
 
-      virtual void probe_args(argument* base_arg, std::stringstream& s) {
+      virtual void probe_args(argument* base_arg,
+                              interface_callbacks::writer::base_writer& w) {
         for (std::vector<argument*>::iterator it = _subarguments.begin();
              it != _subarguments.end(); ++it) {
-          (*it)->probe_args(base_arg, s);
+          (*it)->probe_args(base_arg, w);
         }
       }
 
-      void find_arg(std::string name,
-                    std::string prefix,
+      void find_arg(const std::string& name,
+                    const std::string& prefix,
                     std::vector<std::string>& valid_paths) {
         argument::find_arg(name, prefix, valid_paths);
 
-        prefix += _name + " ";
+        std::string new_prefix = prefix + _name + " ";
         for (std::vector<argument*>::iterator it = _subarguments.begin();
              it != _subarguments.end(); ++it)
-          (*it)->find_arg(name, prefix, valid_paths);
+          (*it)->find_arg(name, new_prefix, valid_paths);
       }
 
       std::vector<argument*>& subarguments() {
         return _subarguments;
       }
 
-      argument* arg(const std::string name) {
+      argument* arg(const std::string& name) {
         for (std::vector<argument*>::iterator it = _subarguments.begin();
              it != _subarguments.end(); ++it)
           if ( name == (*it)->name() )
