@@ -218,7 +218,7 @@ namespace stan {
 
         if (num_init_tries > MAX_INIT_TRIES) {
           std::stringstream R_ss, MAX_INIT_TRIES_ss;
-          R_ss << -R;
+          R_ss << R;
           MAX_INIT_TRIES_ss << MAX_INIT_TRIES;
 
           writer();
@@ -300,7 +300,7 @@ namespace stan {
 
           if (num_init_tries > MAX_INIT_TRIES) {
             std::stringstream R_ss, MAX_INIT_TRIES_ss;
-            R_ss << -R;
+            R_ss << R;
             MAX_INIT_TRIES_ss << MAX_INIT_TRIES;
 
             writer();
