@@ -2,6 +2,7 @@
 #define STAN_MATH_PRIM_MAT_FUN_CHOLESKY_DECOMPOSE_HPP
 
 #include <stan/math/prim/mat/fun/Eigen.hpp>
+#include <stan/math/prim/mat/err/check_pos_definite.hpp>
 #include <stan/math/prim/mat/err/check_square.hpp>
 #include <stan/math/prim/mat/err/check_symmetric.hpp>
 
@@ -16,7 +17,8 @@ namespace stan {
      * <p>\f$A = L \times L^T\f$.
      * @param m Symmetrix matrix.
      * @return Square root of matrix.
-     * @throw std::domain_error if m is not a symmetric matrix.
+     * @throw std::domain_error if m is not a symmetric matrix or
+     *   if m is not positive definite (if m has more than 0 elements)
      */
     template <typename T>
     Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>
@@ -27,6 +29,7 @@ namespace stan {
       Eigen::LLT<Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic> >
         llt(m.rows());
       llt.compute(m);
+      stan::math::check_pos_definite("cholesky_decompose", "m", llt);
       return llt.matrixL();
     }
 
