@@ -10,22 +10,20 @@
 namespace stan {
   namespace math {
 
-    using Eigen::Dynamic;
-    using Eigen::Matrix;
-    using boost::math::tools::promote_args;
-
     template <typename T1, typename T2, int R, int C>
-    inline Matrix
-    <typename promote_args<T1, T2>::type, Dynamic, Dynamic>
-    quad_form_diag(const Matrix<T1, Dynamic, Dynamic>& mat,
-                   const Matrix<T2, R, C>& vec) {
+    inline Eigen::Matrix <
+    typename boost::math::tools::promote_args<T1, T2>::type,
+      Eigen::Dynamic, Eigen::Dynamic>
+    quad_form_diag(const Eigen::Matrix<T1, Eigen::Dynamic, Eigen::Dynamic>& mat,
+                   const Eigen::Matrix<T2, R, C>& vec) {
+      using boost::math::tools::promote_args;
       stan::math::check_vector("quad_form_diag", "vec", vec);
       stan::math::check_square("quad_form_diag", "mat", mat);
       int size = vec.size();
       stan::math::check_equal("quad_form_diag", "matrix size", mat.rows(),
                               size);
-      Matrix<typename promote_args<T1, T2>::type, Dynamic, Dynamic>
-        result(size, size);
+      Eigen::Matrix<typename promote_args<T1, T2>::type,
+        Eigen::Dynamic, Eigen::Dynamic> result(size, size);
       for (int i = 0; i < size; i++) {
         result(i, i) = vec(i)*vec(i)*mat(i, i);
         for (int j = i+1; j < size; ++j) {
