@@ -7,6 +7,11 @@
 #include <cmath>
 #include <valarray>
 
+#ifdef _MSC_VER
+#include <boost/math/special_functions/expm1.hpp>
+using boost::math::expm1;
+#endif
+
 namespace stan {
   namespace math {
 
